@@ -48,9 +48,7 @@ from rando import *
 from randsvd import *
 from redheff import *
 from riemann import *
-from rogues import *
 from smoke import *
-from test import *
 from triw import *
 from wathen import *
 from wilk import *
